@@ -300,7 +300,7 @@ def _check_certificates(
         if not cert_deployment.verified_certificate_chain:
             issues_with_certificates[
                 "certificate_path_validation"
-            ] = f"Certificate not path validation failed for {leaf_cert.subject.rfc4514_string()}."
+            ] = f"Certificate path validation failed for {leaf_cert.subject.rfc4514_string()}."
 
         # Validate the public key
         public_key = leaf_cert.public_key()
@@ -324,7 +324,7 @@ def _check_certificates(
         else:
             deployed_key_algorithms.add(public_key.__class__.__name__)
 
-        deployed_signature_algorithms.add(leaf_cert.signature_algorithm_oid._name)
+        deployed_signature_algorithms.add(leaf_cert.signature_algorithm_oid._name)  # type: ignore
 
         # Validate the cert's lifespan
         leaf_cert_lifespan = leaf_cert.not_valid_after - leaf_cert.not_valid_before
