@@ -4,13 +4,10 @@ from pathlib import Path
 from typing import Any, List, Optional
 
 import pydantic
-from cryptography import x509
 from cryptography.hazmat.primitives import hashes
 from cryptography.hazmat.primitives.asymmetric.rsa import RSAPublicKey
 from cryptography.hazmat.primitives.serialization import Encoding
-from cryptography.x509 import NameAttribute
-from cryptography.x509.ocsp import OCSPResponseStatus
-from cryptography.x509.oid import ObjectIdentifier  # type: ignore
+from cryptography.x509 import NameAttribute, ObjectIdentifier, Name, Certificate, ocsp
 from cryptography.hazmat.primitives.asymmetric.ec import EllipticCurvePublicKey
 
 from sslyze import (
@@ -20,26 +17,22 @@ from sslyze import (
     PathValidationResult,
     TrustStore,
 )
+from sslyze.json.pydantic_utils import BaseModelWithOrmMode
 from sslyze.json.scan_attempt_json import ScanCommandAttemptAsJson
 from sslyze.plugins.certificate_info._certificate_utils import (
     get_public_key_sha256,
-    extract_dns_subject_alternative_names,
+    parse_subject_alternative_name_extension,
 )
 
 
-class _BaseModelWithOrmMode(pydantic.BaseModel):
-    class Config:
-        orm_mode = True
-
-
-class CertificateInfoExtraArgumentAsJson(_BaseModelWithOrmMode):
+class CertificateInfoExtraArgumentAsJson(BaseModelWithOrmMode):
     custom_ca_file: Path
 
 
 CertificateInfoExtraArgumentAsJson.__doc__ = CertificateInfoExtraArgument.__doc__  # type: ignore
 
 
-class _PublicKeyAsJson(_BaseModelWithOrmMode):
+class _PublicKeyAsJson(BaseModelWithOrmMode):
     algorithm: str
     key_size: Optional[int]  # None for Ed25519PublicKey and Ed448PublicKey
 
@@ -72,16 +65,19 @@ class _PublicKeyAsJson(_BaseModelWithOrmMode):
         )
 
 
-class _ObjectIdentifierAsJson(_BaseModelWithOrmMode):
+class _ObjectIdentifierAsJson(BaseModelWithOrmMode):
     name: str
     dotted_string: str
 
     @classmethod
     def from_orm(cls, oid: ObjectIdentifier) -> "_ObjectIdentifierAsJson":
-        return cls(name=oid._name, dotted_string=oid.dotted_string)
+        return cls(
+            name=oid._name,  # type: ignore
+            dotted_string=oid.dotted_string,
+        )
 
 
-class _NameAttributeAsJson(_BaseModelWithOrmMode):
+class _NameAttributeAsJson(BaseModelWithOrmMode):
     oid: _ObjectIdentifierAsJson
     value: str
     rfc4514_string: str
@@ -95,22 +91,28 @@ class _NameAttributeAsJson(_BaseModelWithOrmMode):
         )
 
 
-class _X509NameAsJson(_BaseModelWithOrmMode):
+class _X509NameAsJson(BaseModelWithOrmMode):
     rfc4514_string: str
     attributes: List[_NameAttributeAsJson]
 
     @classmethod
-    def from_orm(cls, name: x509.name.Name) -> "_X509NameAsJson":
+    def from_orm(cls, name: Name) -> "_X509NameAsJson":
         return cls(
             rfc4514_string=name.rfc4514_string(), attributes=[_NameAttributeAsJson.from_orm(attr) for attr in name]
         )
 
 
 class _SubjAltNameAsJson(pydantic.BaseModel):
-    dns: List[str]
+
+    # TODO(6.0.0): Remove the Config, alias and default value as the name "dns" is deprecated
+    class Config:
+        allow_population_by_field_name = True
+
+    dns_names: List[str] = pydantic.Field(alias="dns")
+    ip_addresses: List[pydantic.IPvAnyAddress] = []
 
 
-class _HashAlgorithmAsJson(_BaseModelWithOrmMode):
+class _HashAlgorithmAsJson(BaseModelWithOrmMode):
     name: str
     digest_size: int
 
@@ -119,7 +121,7 @@ class _HashAlgorithmAsJson(_BaseModelWithOrmMode):
         return cls(name=hash_algorithm.name, digest_size=hash_algorithm.digest_size)
 
 
-class _CertificateAsJson(_BaseModelWithOrmMode):
+class _CertificateAsJson(BaseModelWithOrmMode):
     as_pem: str
     hpkp_pin: str  # RFC 7469
     fingerprint_sha1: str
@@ -143,7 +145,7 @@ class _CertificateAsJson(_BaseModelWithOrmMode):
     public_key: _PublicKeyAsJson
 
     @classmethod
-    def from_orm(cls, certificate: x509.Certificate) -> "_CertificateAsJson":
+    def from_orm(cls, certificate: Certificate) -> "_CertificateAsJson":
         signature_hash_algorithm: Optional[_HashAlgorithmAsJson]
         if certificate.signature_hash_algorithm:
             signature_hash_algorithm = _HashAlgorithmAsJson.from_orm(certificate.signature_hash_algorithm)
@@ -164,6 +166,8 @@ class _CertificateAsJson(_BaseModelWithOrmMode):
         except ValueError:
             issuer_field = None
 
+        subj_alt_name_ext = parse_subject_alternative_name_extension(certificate)
+
         return cls(
             as_pem=certificate.public_bytes(Encoding.PEM).decode("ascii"),
             hpkp_pin=b64encode(get_public_key_sha256(certificate)).decode("ascii"),
@@ -172,7 +176,10 @@ class _CertificateAsJson(_BaseModelWithOrmMode):
             serial_number=certificate.serial_number,
             not_valid_before=certificate.not_valid_before,
             not_valid_after=certificate.not_valid_after,
-            subject_alternative_name=_SubjAltNameAsJson(dns=extract_dns_subject_alternative_names(certificate)),
+            subject_alternative_name=_SubjAltNameAsJson(
+                dns_names=subj_alt_name_ext.dns_names,
+                ip_addresses=subj_alt_name_ext.ip_addresses,
+            ),
             signature_hash_algorithm=signature_hash_algorithm,
             signature_algorithm_oid=certificate.signature_algorithm_oid,
             subject=subject_field,
@@ -181,7 +188,7 @@ class _CertificateAsJson(_BaseModelWithOrmMode):
         )
 
 
-class _OcspResponseAsJson(_BaseModelWithOrmMode):
+class _OcspResponseAsJson(BaseModelWithOrmMode):
     response_status: str
 
     certificate_status: Optional[str]
@@ -194,9 +201,9 @@ class _OcspResponseAsJson(_BaseModelWithOrmMode):
     serial_number: Optional[int]
 
     @classmethod
-    def from_orm(cls, ocsp_response: x509.ocsp.OCSPResponse) -> "_OcspResponseAsJson":
+    def from_orm(cls, ocsp_response: ocsp.OCSPResponse) -> "_OcspResponseAsJson":
         response_status = ocsp_response.response_status.name
-        if ocsp_response.response_status != OCSPResponseStatus.SUCCESSFUL:
+        if ocsp_response.response_status != ocsp.OCSPResponseStatus.SUCCESSFUL:
             return cls(
                 response_status=response_status,
                 certificate_status=None,
@@ -218,7 +225,7 @@ class _OcspResponseAsJson(_BaseModelWithOrmMode):
             )
 
 
-class _TrustStoreAsJson(_BaseModelWithOrmMode):
+class _TrustStoreAsJson(BaseModelWithOrmMode):
     path: Path
     name: str
     version: str
@@ -228,7 +235,7 @@ class _TrustStoreAsJson(_BaseModelWithOrmMode):
 _TrustStoreAsJson.__doc__ = TrustStore.__doc__  # type: ignore
 
 
-class _PathValidationResultAsJson(_BaseModelWithOrmMode):
+class _PathValidationResultAsJson(BaseModelWithOrmMode):
     trust_store: _TrustStoreAsJson
     verified_certificate_chain: Optional[List[_CertificateAsJson]]
     openssl_error_string: Optional[str]
@@ -238,7 +245,7 @@ class _PathValidationResultAsJson(_BaseModelWithOrmMode):
 _PathValidationResultAsJson.__doc__ = PathValidationResult.__doc__  # type: ignore
 
 
-class _CertificateDeploymentAnalysisResultAsJson(_BaseModelWithOrmMode):
+class _CertificateDeploymentAnalysisResultAsJson(BaseModelWithOrmMode):
     received_certificate_chain: List[_CertificateAsJson]
     leaf_certificate_subject_matches_hostname: bool
     leaf_certificate_has_must_staple_extension: bool
@@ -260,7 +267,7 @@ class _CertificateDeploymentAnalysisResultAsJson(_BaseModelWithOrmMode):
 _CertificateDeploymentAnalysisResultAsJson.__doc__ = CertificateDeploymentAnalysisResult.__doc__  # type: ignore
 
 
-class CertificateInfoScanResultAsJson(_BaseModelWithOrmMode):
+class CertificateInfoScanResultAsJson(BaseModelWithOrmMode):
     hostname_used_for_server_name_indication: str
     certificate_deployments: List[_CertificateDeploymentAnalysisResultAsJson]
 
