@@ -3,9 +3,9 @@ import types
 from dataclasses import dataclass
 from typing import List, Optional
 
-import pydantic
 from nassl._nassl import WantReadError
 
+from sslyze.json.pydantic_utils import BaseModelWithOrmModeAndForbid
 from sslyze.json.scan_attempt_json import ScanCommandAttemptAsJson
 from sslyze.plugins.plugin_base import (
     ScanCommandResult,
@@ -37,8 +37,8 @@ class HeartbleedScanResult(ScanCommandResult):
     is_vulnerable_to_heartbleed: bool
 
 
-# Identical fields in the JSON output
-HeartbleedScanResultAsJson = pydantic.dataclasses.dataclass(HeartbleedScanResult, frozen=True)
+class HeartbleedScanResultAsJson(BaseModelWithOrmModeAndForbid):
+    is_vulnerable_to_heartbleed: bool
 
 
 class HeartbleedScanAttemptAsJson(ScanCommandAttemptAsJson):
