@@ -3,9 +3,9 @@ import types
 from dataclasses import dataclass
 from typing import List, Optional
 
-import pydantic
 from nassl._nassl import WantReadError
 
+from sslyze.json.pydantic_utils import BaseModelWithOrmModeAndForbid
 from sslyze.json.scan_attempt_json import ScanCommandAttemptAsJson
 from sslyze.plugins.plugin_base import (
     ScanCommandResult,
@@ -38,8 +38,8 @@ class OpenSslCcsInjectionScanResult(ScanCommandResult):
     is_vulnerable_to_ccs_injection: bool
 
 
-# Identical fields in the JSON output
-OpenSslCcsInjectionScanResultAsJson = pydantic.dataclasses.dataclass(OpenSslCcsInjectionScanResult, frozen=True)
+class OpenSslCcsInjectionScanResultAsJson(BaseModelWithOrmModeAndForbid):
+    is_vulnerable_to_ccs_injection: bool
 
 
 class OpenSslCcsInjectionScanAttemptAsJson(ScanCommandAttemptAsJson):
