@@ -1,23 +1,22 @@
-import json
-from dataclasses import dataclass, asdict
+from dataclasses import dataclass
 from typing import Dict
 
 import pytest
 from nassl.ssl_client import ClientCertificateRequested
 
-from sslyze import JsonEncoder
 from sslyze.plugins.http_headers_plugin import (
     HttpHeadersImplementation,
     HttpHeadersScanResult,
     _detect_http_redirection,
+    HttpHeadersScanResultAsJson,
 )
-from sslyze.server_connectivity import ServerConnectivityTester
 
 from sslyze.server_setting import (
-    ServerNetworkLocationViaDirectConnection,
+    ServerNetworkLocation,
     ServerNetworkConfiguration,
     ClientAuthenticationCredentials,
 )
+from tests.connectivity_utils import check_connectivity_to_server_and_return_info
 from tests.markers import can_only_run_on_linux_64
 from tests.openssl_server import ClientAuthConfigEnum, LegacyOpenSslServer, ModernOpenSslServer
 
@@ -25,8 +24,8 @@ from tests.openssl_server import ClientAuthConfigEnum, LegacyOpenSslServer, Mode
 class TestHttpHeadersPlugin:
     def test_hsts_enabled(self):
         # Given a server to scan that has HSTS enabled
-        server_location = ServerNetworkLocationViaDirectConnection.with_ip_address_lookup("hsts.badssl.com", 443)
-        server_info = ServerConnectivityTester().perform(server_location)
+        server_location = ServerNetworkLocation("hsts.badssl.com", 443)
+        server_info = check_connectivity_to_server_and_return_info(server_location)
 
         # When scanning for HTTP headers, it succeeds
         result: HttpHeadersScanResult = HttpHeadersImplementation.scan_server(server_info)
@@ -35,17 +34,14 @@ class TestHttpHeadersPlugin:
         assert result.http_request_sent
         assert result.http_path_redirected_to
         assert result.strict_transport_security_header
-        assert not result.public_key_pins_header
-        assert not result.public_key_pins_report_only_header
-        assert not result.expect_ct_header
 
         # And a CLI output can be generated
         assert HttpHeadersImplementation.cli_connector_cls.result_to_console_output(result)
 
-    def test_hsts_and_hpkp_disabled(self):
+    def test_all_headers_disabled(self):
         # Given a server to scan that does not have security headers
-        server_location = ServerNetworkLocationViaDirectConnection.with_ip_address_lookup("expired.badssl.com", 443)
-        server_info = ServerConnectivityTester().perform(server_location)
+        server_location = ServerNetworkLocation("expired.badssl.com", 443)
+        server_info = check_connectivity_to_server_and_return_info(server_location)
 
         # When scanning for HTTP headers, it succeeds
         result: HttpHeadersScanResult = HttpHeadersImplementation.scan_server(server_info)
@@ -54,28 +50,11 @@ class TestHttpHeadersPlugin:
         assert result.http_request_sent
         assert result.http_path_redirected_to
         assert not result.strict_transport_security_header
-        assert not result.public_key_pins_header
-        assert not result.public_key_pins_report_only_header
         assert not result.expect_ct_header
 
         # And a CLI output can be generated
         assert HttpHeadersImplementation.cli_connector_cls.result_to_console_output(result)
 
-    def test_expect_ct_enabled(self):
-        # Given a server to scan that has Expect-CT enabled
-        server_location = ServerNetworkLocationViaDirectConnection.with_ip_address_lookup("github.com", 443)
-        server_info = ServerConnectivityTester().perform(server_location)
-
-        # When scanning for HTTP headers, it succeeds
-        result: HttpHeadersScanResult = HttpHeadersImplementation.scan_server(server_info)
-
-        # And the Expect-CT header was detected
-        assert result.expect_ct_header
-        assert result.expect_ct_header.max_age >= 0
-
-        # And a CLI output can be generated
-        assert HttpHeadersImplementation.cli_connector_cls.result_to_console_output(result)
-
     @can_only_run_on_linux_64
     def test_http_error(self):
         # Given a server to scan
@@ -83,10 +62,10 @@ class TestHttpHeadersPlugin:
             # And the server will trigger an error when receiving an HTTP request
             should_reply_to_http_requests=False
         ) as server:
-            server_location = ServerNetworkLocationViaDirectConnection(
+            server_location = ServerNetworkLocation(
                 hostname=server.hostname, ip_address=server.ip_address, port=server.port
             )
-            server_info = ServerConnectivityTester().perform(server_location)
+            server_info = check_connectivity_to_server_and_return_info(server_location)
 
             # When scanning for HTTP headers, it succeeds
             result: HttpHeadersScanResult = HttpHeadersImplementation.scan_server(server_info)
@@ -97,15 +76,12 @@ class TestHttpHeadersPlugin:
 
         # And the other result fields are not set
         assert not result.http_path_redirected_to
-        assert not result.public_key_pins_header
-        assert not result.public_key_pins_report_only_header
-        assert not result.expect_ct_header
 
         # And a CLI output can be generated
         assert HttpHeadersImplementation.cli_connector_cls.result_to_console_output(result)
 
         # And the result can be converted to JSON
-        result_as_json = json.dumps(asdict(result), cls=JsonEncoder)
+        result_as_json = HttpHeadersScanResultAsJson.from_orm(result).json()
         assert result_as_json
 
     @can_only_run_on_linux_64
@@ -113,10 +89,10 @@ class TestHttpHeadersPlugin:
         # Given a server that requires client authentication
         with LegacyOpenSslServer(client_auth_config=ClientAuthConfigEnum.REQUIRED) as server:
             # And sslyze does NOT provide a client certificate
-            server_location = ServerNetworkLocationViaDirectConnection(
+            server_location = ServerNetworkLocation(
                 hostname=server.hostname, ip_address=server.ip_address, port=server.port
             )
-            server_info = ServerConnectivityTester().perform(server_location)
+            server_info = check_connectivity_to_server_and_return_info(server_location)
 
             # When scanning for HTTP headers, it fails
             with pytest.raises(ClientCertificateRequested):
@@ -126,7 +102,7 @@ class TestHttpHeadersPlugin:
     def test_works_when_client_auth_succeeded(self):
         # Given a server that requires client authentication
         with LegacyOpenSslServer(client_auth_config=ClientAuthConfigEnum.REQUIRED) as server:
-            server_location = ServerNetworkLocationViaDirectConnection(
+            server_location = ServerNetworkLocation(
                 hostname=server.hostname, ip_address=server.ip_address, port=server.port
             )
             # And sslyze provides a client certificate
@@ -136,15 +112,12 @@ class TestHttpHeadersPlugin:
                     certificate_chain_path=server.get_client_certificate_path(), key_path=server.get_client_key_path()
                 ),
             )
-            server_info = ServerConnectivityTester().perform(server_location, network_config)
+            server_info = check_connectivity_to_server_and_return_info(server_location, network_config)
 
             # When scanning for HTTP headers, it succeeds
             result: HttpHeadersScanResult = HttpHeadersImplementation.scan_server(server_info)
 
             assert not result.strict_transport_security_header
-            assert not result.public_key_pins_header
-            assert not result.public_key_pins_report_only_header
-            assert not result.expect_ct_header
 
 
 @dataclass
@@ -153,15 +126,17 @@ class _MockHttpResponse:
     _headers: Dict[str, str]
 
     def getheader(self, name: str, default=None):
-        """Replicate HTTPResponse's API.
-        """
+        """Replicate HTTPResponse's API."""
         return self._headers[name]
 
 
 class TestHttpRedirection:
     def test_no_redirection(self):
         # Given an HTTP response with no redirection
-        http_response = _MockHttpResponse(status=200, _headers={},)
+        http_response = _MockHttpResponse(
+            status=200,
+            _headers={},
+        )
 
         # When it gets parsed
         next_location_path = _detect_http_redirection(
@@ -173,7 +148,10 @@ class TestHttpRedirection:
 
     def test_redirection_relative_url(self):
         # Given an HTTP response with a redirection to a relative URL
-        http_response = _MockHttpResponse(status=302, _headers={"Location": "/newpath"},)
+        http_response = _MockHttpResponse(
+            status=302,
+            _headers={"Location": "/newpath"},
+        )
 
         # When it gets parsed
         next_location_path = _detect_http_redirection(
@@ -185,7 +163,10 @@ class TestHttpRedirection:
 
     def test_redirection_absolute_url_same_server(self):
         # Given an HTTP response with a redirection to an absolute URL that points to the same server
-        http_response = _MockHttpResponse(status=302, _headers={"Location": "https://lol.com/newpath"},)
+        http_response = _MockHttpResponse(
+            status=302,
+            _headers={"Location": "https://lol.com/newpath"},
+        )
 
         # When it gets parsed
         next_location_path = _detect_http_redirection(
@@ -197,7 +178,10 @@ class TestHttpRedirection:
 
     def test_redirection_absolute_url_different_hostname(self):
         # Given an HTTP response with a redirection to an absolute URL that points to a different hostname
-        http_response = _MockHttpResponse(status=302, _headers={"Location": "https://otherdomain.com/newpath"},)
+        http_response = _MockHttpResponse(
+            status=302,
+            _headers={"Location": "https://otherdomain.com/newpath"},
+        )
 
         # When it gets parsed
         next_location_path = _detect_http_redirection(
@@ -209,7 +193,10 @@ class TestHttpRedirection:
 
     def test_redirection_absolute_url_different_port(self):
         # Given an HTTP response with a redirection to an absolute URL that points to a different port
-        http_response = _MockHttpResponse(status=302, _headers={"Location": "https://lol.com:444/newpath"},)
+        http_response = _MockHttpResponse(
+            status=302,
+            _headers={"Location": "https://lol.com:444/newpath"},
+        )
 
         # When it gets parsed
         next_location_path = _detect_http_redirection(
