@@ -4,13 +4,13 @@ from sslyze.plugins.session_renegotiation_plugin import (
     SessionRenegotiationImplementation,
     SessionRenegotiationScanResult,
 )
-from sslyze.server_connectivity import ServerConnectivityTester
 
 from sslyze.server_setting import (
-    ServerNetworkLocationViaDirectConnection,
+    ServerNetworkLocation,
     ClientAuthenticationCredentials,
     ServerNetworkConfiguration,
 )
+from tests.connectivity_utils import check_connectivity_to_server_and_return_info
 from tests.markers import can_only_run_on_linux_64
 from tests.openssl_server import LegacyOpenSslServer, ClientAuthConfigEnum
 import pytest
@@ -19,8 +19,8 @@ import pytest
 class TestSessionRenegotiationPlugin:
     def test_renegotiation_good(self):
         # Given a server that is NOT vulnerable to insecure reneg nor client reneg DOS
-        server_location = ServerNetworkLocationViaDirectConnection.with_ip_address_lookup("www.google.com", 443)
-        server_info = ServerConnectivityTester().perform(server_location)
+        server_location = ServerNetworkLocation("www.google.com", 443)
+        server_info = check_connectivity_to_server_and_return_info(server_location)
 
         # When testing for insecure reneg, it succeeds
         result: SessionRenegotiationScanResult = SessionRenegotiationImplementation.scan_server(server_info)
@@ -36,10 +36,10 @@ class TestSessionRenegotiationPlugin:
     def test_renegotiation_is_vulnerable_to_client_renegotiation_dos(self):
         # Given a server that is vulnerable to client renegotiation DOS
         with LegacyOpenSslServer() as server:
-            server_location = ServerNetworkLocationViaDirectConnection(
+            server_location = ServerNetworkLocation(
                 hostname=server.hostname, ip_address=server.ip_address, port=server.port
             )
-            server_info = ServerConnectivityTester().perform(server_location)
+            server_info = check_connectivity_to_server_and_return_info(server_location)
 
             # When testing for insecure reneg, it succeeds
             result: SessionRenegotiationScanResult = SessionRenegotiationImplementation.scan_server(server_info)
@@ -55,10 +55,10 @@ class TestSessionRenegotiationPlugin:
         # Given a server that requires client authentication
         with LegacyOpenSslServer(client_auth_config=ClientAuthConfigEnum.REQUIRED) as server:
             # And sslyze does NOT provide a client certificate
-            server_location = ServerNetworkLocationViaDirectConnection(
+            server_location = ServerNetworkLocation(
                 hostname=server.hostname, ip_address=server.ip_address, port=server.port
             )
-            server_info = ServerConnectivityTester().perform(server_location)
+            server_info = check_connectivity_to_server_and_return_info(server_location)
 
             # When testing for insecure reneg, it fails
             with pytest.raises(ClientCertificateRequested):
@@ -68,7 +68,7 @@ class TestSessionRenegotiationPlugin:
     def test_works_when_client_auth_succeeded(self):
         # Given a server that is vulnerable and that requires client authentication
         with LegacyOpenSslServer(client_auth_config=ClientAuthConfigEnum.REQUIRED) as server:
-            server_location = ServerNetworkLocationViaDirectConnection(
+            server_location = ServerNetworkLocation(
                 hostname=server.hostname, ip_address=server.ip_address, port=server.port
             )
             # And sslyze provides a client certificate
@@ -78,7 +78,7 @@ class TestSessionRenegotiationPlugin:
                     certificate_chain_path=server.get_client_certificate_path(), key_path=server.get_client_key_path()
                 ),
             )
-            server_info = ServerConnectivityTester().perform(server_location, network_config)
+            server_info = check_connectivity_to_server_and_return_info(server_location, network_config)
 
             # When testing for insecure reneg, it succeeds
             result: SessionRenegotiationScanResult = SessionRenegotiationImplementation.scan_server(server_info)
